pub struct CryptoKeyIndex;Trait Implementations
Sourceimpl Clone for CryptoKeyIndex
impl Clone for CryptoKeyIndex
Sourcefn clone(&self) -> CryptoKeyIndex
fn clone(&self) -> CryptoKeyIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CryptoKeyIndex
impl Debug for CryptoKeyIndex
Sourceimpl<'de> Deserialize<'de> for CryptoKeyIndex
impl<'de> Deserialize<'de> for CryptoKeyIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for CryptoKeyIndex
impl Hash for CryptoKeyIndex
Sourceimpl Indexable for CryptoKeyIndex
impl Indexable for CryptoKeyIndex
Sourceconst DISPLAY_PREFIX: &'static str = "CryptoKey"
const DISPLAY_PREFIX: &'static str = "CryptoKey"
The string prefix to display when debug printing an instance of
this type.
Sourceimpl MallocSizeOf for CryptoKeyIndex
impl MallocSizeOf for CryptoKeyIndex
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl Ord for CryptoKeyIndex
impl Ord for CryptoKeyIndex
Sourcefn cmp(&self, other: &CryptoKeyIndex) -> Ordering
fn cmp(&self, other: &CryptoKeyIndex) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CryptoKeyIndex
impl PartialEq for CryptoKeyIndex
Sourceimpl PartialOrd for CryptoKeyIndex
impl PartialOrd for CryptoKeyIndex
Sourceimpl Serialize for CryptoKeyIndex
impl Serialize for CryptoKeyIndex
impl Copy for CryptoKeyIndex
impl Eq for CryptoKeyIndex
impl StructuralPartialEq for CryptoKeyIndex