pub struct FileIndex;Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FileIndex
impl<'de> Deserialize<'de> for FileIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Indexable for FileIndex
impl Indexable for FileIndex
Sourceconst DISPLAY_PREFIX: &'static str = "File"
const DISPLAY_PREFIX: &'static str = "File"
The string prefix to display when debug printing an instance of
this type.
Sourceimpl MallocSizeOf for FileIndex
impl MallocSizeOf for FileIndex
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl Ord for FileIndex
impl Ord for FileIndex
Sourceimpl PartialOrd for FileIndex
impl PartialOrd for FileIndex
impl Copy for FileIndex
impl Eq for FileIndex
impl StructuralPartialEq for FileIndex