pub struct FileListIndex;Trait Implementations
Sourceimpl Clone for FileListIndex
impl Clone for FileListIndex
Sourcefn clone(&self) -> FileListIndex
fn clone(&self) -> FileListIndex
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FileListIndex
impl Debug for FileListIndex
Sourceimpl<'de> Deserialize<'de> for FileListIndex
impl<'de> Deserialize<'de> for FileListIndex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for FileListIndex
impl Hash for FileListIndex
Sourceimpl Indexable for FileListIndex
impl Indexable for FileListIndex
Sourceconst DISPLAY_PREFIX: &'static str = "FileList"
const DISPLAY_PREFIX: &'static str = "FileList"
The string prefix to display when debug printing an instance of
this type.
Sourceimpl MallocSizeOf for FileListIndex
impl MallocSizeOf for FileListIndex
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl Ord for FileListIndex
impl Ord for FileListIndex
Sourcefn cmp(&self, other: &FileListIndex) -> Ordering
fn cmp(&self, other: &FileListIndex) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for FileListIndex
impl PartialEq for FileListIndex
Sourceimpl PartialOrd for FileListIndex
impl PartialOrd for FileListIndex
Sourceimpl Serialize for FileListIndex
impl Serialize for FileListIndex
impl Copy for FileListIndex
impl Eq for FileListIndex
impl StructuralPartialEq for FileListIndex